# astr

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

## Packages that use `astr`

## Developer Guide

### Setup

``` sh
# create conda environment
$ mamba env create -f env.yml

# update conda environment
$ mamba env update -n astr --file env.yml
```

### Install

``` sh
pip install -e .

# install from pypi
pip install astr
```

### nbdev

``` sh
# activate conda environment
$ conda activate astr

# make sure the astr package is installed in development mode
$ pip install -e .

# make changes under nbs/ directory
# ...

# compile to have changes apply to the astr package
$ nbdev_prepare
```

### Publishing

``` sh
# publish to pypi
$ nbdev_pypi

# publish to conda
$ nbdev_conda --build_args '-c conda-forge'
$ nbdev_conda --mambabuild --build_args '-c conda-forge -c dsm-72'
```

# Usage

## Installation

Install latest from the GitHub
[repository](https://github.com/dsm-72/astr):

``` sh
$ pip install git+https://github.com/dsm-72/astr.git
```

or from [conda](https://anaconda.org/dsm-72/astr)

``` sh
$ conda install -c dsm-72 astr
```

or from [pypi](https://pypi.org/project/astr/)

``` sh
$ pip install astr
```

## Documentation

Documentation can be found hosted on GitHub
[repository](https://github.com/dsm-72/astr)
[pages](https://dsm-72.github.io/astr/). Additionally you can find
package manager specific guidelines on
[conda](https://anaconda.org/dsm-72/astr) and
[pypi](https://pypi.org/project/astr/) respectively.

### A = Alias

### C = ClassVar

### Q = Optional

### E = (Over)-Engineered

### Z = Custom

### R = Rich

### P = Plot

### D = Data

### B = Bio

### M = Machine Learning
